================
VISTA Simulator
================

.. image:: https://img.shields.io/pypi/v/vista.svg
        :target: https://pypi.python.org/pypi/vista

.. image:: https://img.shields.io/travis/aamini/vista.svg
        :target: https://travis-ci.com/aamini/vista

.. image:: https://readthedocs.org/projects/vista/badge/?version=latest
        :target: https://vista.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: docs/assets/icon_200.png

**VISTA** (Virtual Image Synthesis and Transformation for Autonomy) is a **data-driven simulator for training and evaluating full-scale autonomous vehicles**.

For more details on VISTA please refer to our recent publication: `Learning Robust Control Policies for End-to-End
Autonomous Driving From Data-Driven Simulation <https://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=8957584>`_

.. code-block:: 

    @article{amini2020learning,
        title={Learning Robust Control Policies for End-to-End Autonomous Driving from Data-Driven Simulation},
        author={Amini, Alexander and Gilitschenski, Igor and Phillips, Jacob and Moseyko, Julia and Banerjee, Rohan and Karaman, Sertac and Rus, Daniela},
        journal={IEEE Robotics and Automation Letters},    
        year={2020},
        publisher={IEEE}
    }



Features
--------
Coming soon! This repository is currently in development and we will be announcing the full release very soon! 


Misc
-------
* Documentation: https://vista.readthedocs.io.
* Free software: MIT license
* `Package Template <https://github.com/audreyr/cookiecutter-pypackage>`_

